@@ -1,15 +1,14 @@
 package OpenInteract::Handler::NewUser;
 
-# $Id: NewUser.pm,v 1.7 2002/04/13 17:25:03 lachoy Exp $
+# $Id: NewUser.pm,v 1.8 2002/05/13 12:17:43 lachoy Exp $
 
 use strict;
-use Email::Valid;
 use Data::Dumper  qw( Dumper );
 use SPOPS::Secure qw( :level :scope );
 use SPOPS::Utility;
 
 @OpenInteract::Handler::NewUser::ISA     = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::NewUser::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::NewUser::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::NewUser::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::NewUser::default_method    = 'show';
@@ -36,7 +35,7 @@ sub edit {
 
     # First ensure the email is good
 
-    unless ( $email and Email::Valid->address( $email ) ) {
+    unless ( $class->_validate_email( $email ) ) {
         $R->throw({ code       => 421,
                     type       => 'email',
                     system_msg => "Invalid email address: $email",
@@ -48,7 +47,7 @@ sub edit {
 
     # Next, ensure they typed in a login
 
-    unless( $login ) {
+    unless ( $login ) {
         my $error_msg = 'You cannot create an account without entering a login!';
         return $class->show( { error_msg     => $error_msg,
                                working_email => $email } );
@@ -157,6 +156,27 @@ the instructions to login and activate your account.
 OK
 }
 
+
+sub _validate_email {
+    my ( $class, $email ) = @_;
+    return undef unless ( $email );
+
+    my $R = OpenInteract::Request->instance;
+    eval "require Email::Valid";
+    unless ( $@ ) {
+        $R->scrib( 1, "Email::Valid loaded ok, using it to validate address" );
+        return Email::Valid->address( $email );
+    }
+
+    $R->scrib( 1, "Email::Valid NOT loaded ok, trying Mail::RFC822::Address" );
+    eval "require Mail::RFC822::Address";
+    if ( $@ ) {
+        $R->scrib( 0, "Mail::RFC822::Address NOT loaded ok, cannot validate!" );
+        return undef;
+    }
+    return Mail::RFC822::Address::valid( $email );
+}
+
 1;
 
 __END__
@@ -196,6 +216,12 @@ Creates the user account and notifies the user with the temporary
 password as well as the fact that the account will be removed in 24
 hours if he/she does not login.
 
+B<Important>: This routine tries to validate the email address using
+either L<Email::Valid|Email::Valid> or if that is not found,
+L<Mail::RFC822::Address|Mail::RFC822::Address>. If neither of these
+modules is found then the email address cannot be validated and the
+user cannot register.
+
 =head1 TO DO
 
 Nothing known.
